<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://club.wpeka.com
 * @since      7.0
 *
 * @package    Wplegalpages_Pro
 * @subpackage Wplegalpages_Pro/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wplegalpages_Pro
 * @subpackage Wplegalpages_Pro/public
 * @author     WPEkaClub <support@wpeka.com>
 */
class Wplegalpages_Pro_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    7.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    7.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    7.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

		add_shortcode( 'wp-legalpage', array( $this, 'wplegalpages_pro_shortcode' ) );
		add_shortcode( 'wp-legalpopup', array( $this, 'wplegalpages_pro_popup_shortcode' ) );
		$lp_general = get_option( 'lp_general' );
		if ( isset( $lp_general['search'] ) && '1' !== $lp_general['search'] ) {
			add_filter( 'posts_where', array( $this, 'wplegalpages_pro_exclude_search_pages' ) );
		}
		$age_verify_popup_setting = get_option( '_lp_require_for' );
		if ( 'site' !== $age_verify_popup_setting && isset( $lp_general['is_adult'] ) && '1' === $lp_general['is_adult'] && ! isset( $_COOKIE['is_user_adult'] ) ) {
			add_action( 'wp_enqueue_scripts', array( $this, 'wplegalpages_pro_adult_scripts' ) );
			add_action( 'wp_footer', array( $this, 'wplegalpages_pro_adult_popup' ) );
		}
		if ( 'site' === $age_verify_popup_setting ) {
			add_action( 'wp_footer', array( $this, 'wplegalpages_pro_verify_overlay' ) );
			add_action( 'the_content', array( $this, 'wplegalpages_pro_restrict_content' ) );
			add_action( 'template_redirect', array( $this, 'wplegalpages_pro_verify' ) );
			if ( $this->wplegalpages_pro_confirmation_required() ) {
				add_action( 'register_form', 'wplegalpages_pro_register_form' );
				add_action( 'register_post', 'wplegalpages_pro_register_check', 10, 3 );
			}
		}
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    7.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wplegalpages_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wplegalpages_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wplegalpages-pro-public' . WPLPP_SUFFIX . '.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    7.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wplegalpages_Pro_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wplegalpages_Pro_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wplegalpages-pro-public' . WPLPP_SUFFIX . '.js', array( 'jquery' ), $this->version, false );
		wp_register_script( $this->plugin_name . 'adult-content', plugin_dir_url( __FILE__ ) . 'js/wplegalpages-pro-public-adult-content' . WPLPP_SUFFIX . '.js', array( 'jquery' ), $this->version, false );
		wp_register_script( $this->plugin_name . 'popups', plugin_dir_url( __FILE__ ) . 'js/wplegalpages-pro-public-popups' . WPLPP_SUFFIX . '.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Process Legal Pages Shortcodes.
	 *
	 * @param Array $atts Shortcode attributes.
	 *
	 * @return string
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_shortcode( $atts ) {
		global $wpdb;
		$legalpages_pro = new Wplegalpages_Pro();
		$atts           = shortcode_atts(
			array(
				'tid' => 1,
			),
			$atts
		);
		$tid            = $atts['tid'];

		$res = $wpdb->get_row( $wpdb->prepare( 'SELECT * from ' . $legalpages_pro->tablename . ' where id= %d', $tid ) ); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared,WordPress.DB.DirectDatabaseQuery,WordPress.DB.DirectDatabaseQuery.NoCaching
		if ( isset( $res->content ) ) {
			$content = $res->content;
		}
		$lp_find    = array( '[Domain]', '[Business Name]', '[Phone]', '[Street]', '[City, State, Zip code]', '[Country]', '[Email]', '[Address]', '[Niche]' );
		$lp_general = get_option( 'lp_general' );
		$content    = str_replace( $lp_find, $lp_general, stripslashes( $content ) );
		$content    = apply_filters( 'wplegalpages_shortcode_content', $content );

		if ( is_single() || is_page() ) {
			return html_entity_decode( $content );
		}
	}

	/**
	 * Process Legal Pages popup shortcode.
	 *
	 * @param Array $atts Shortcode attributes.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_popup_shortcode( $atts ) {
		global $wpdb;
		$legalpages_pro = new Wplegalpages_Pro();
		$atts           = shortcode_atts(
			array(
				'pid' => 1,
			),
			$atts
		);
		$pid            = $atts['pid'];

		$res   = $wpdb->get_row( $wpdb->prepare( 'SELECT * from ' . $legalpages_pro->popuptable . ' where id= %d', $pid ) ); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared,WordPress.DB.DirectDatabaseQuery,WordPress.DB.DirectDatabaseQuery.NoCaching
		$terms = '';
		if ( isset( $res->content ) ) {
			$terms = do_shortcode( $res->content );
		}
		$lp_find    = array( '[Domain]', '[Business Name]', '[Phone]', '[Street]', '[City, State, Zip code]', '[Country]', '[Email]', '[Address]', '[Niche]' );
		$lp_general = get_option( 'lp_general' );
		$terms      = str_replace( $lp_find, $lp_general, stripslashes( $terms ) );
		$terms      = apply_filters( 'wplegalpages_shortcode_content', $terms );

		$content = '<div>
						' . $terms . '
						<p><input type="checkbox" name="lp_accept" id="lp_accept" value="1" onclick="jQuery(\'.accept\').toggle();" /> I agree to the terms and conditions.</p>
						<input type="submit" name="lp_submit" id="lp_submit" value="Accept" class="accept" style="display:none;"/>
						<br/>
					</div>';
		if ( is_single() || is_page() ) {
			add_thickbox();
			?>
			<div id="thick-box" style="display:none;" >
				<p> <?php echo esc_attr( $content ); ?> </p>
			</div>
			<?php
			wp_enqueue_script( $this->plugin_name . 'popups' );
		}
	}

	/**
	 * Enqueues Legal Pages CSS.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_css() {
		?>
		<style type="text/css">
			ul.legalfooter li{
				list-style:none;
				float:left;
				padding-right:20px;
			}
			.accept{
				display:none;
				border: 1px solid #000;
				background:#000;
				color:#fff;
				border-radius:3px;
				-moz-border-radius:3px;
				-webkit-border-radius:3px;
				padding:5px;
			}
		</style>
		<?php
	}

	/**
	 * Disables comments for Legal Pages.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_disable_comments() {
		$post_id = get_the_ID();
		$meta    = get_post_meta( $post_id, 'is_legal', true );
		$general = get_option( 'lp_general' );
		if ( isset( $general['disable_comments'] ) && '1' === $general['disable_comments'] && 'yes' === $meta ) {
			add_filter( 'comments_open', array( $this, 'wplegalpages_pro_disable_page_comments' ) );
		}
	}

	/**
	 * Disables comments for Legal Pages.
	 *
	 * @return bool
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_disable_page_comments() {
		$post = get_post_meta( get_the_ID(), 'is_legal' );

		if ( 'yes' === $post[0] ) {
			$open = false;
		}

		return $open;
	}

	/**
	 * Excludes Legal Pages from search query.
	 *
	 * @param string $where Search query.
	 *
	 * @return string
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_exclude_search_pages( $where = '' ) {
		global $wpdb;
		$exclude = array();

		if ( ! is_admin() && is_search() ) {
			$post_tbl     = $wpdb->prefix . 'posts';
			$postmeta_tbl = $wpdb->prefix . 'postmeta';
			$pagesresult  = $wpdb->get_results( $wpdb->prepare( 'SELECT ' . $post_tbl . '.* FROM ' . $post_tbl . ' as ptbl, ' . $postmeta_tbl . ' as pmtbl WHERE ptbl.ID = pmtbl.post_id and ptbl.post_status=%s AND pmtbl.meta_key=%s', array( 'publish', 'is_legal' ) ) ); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared,WordPress.DB.DirectDatabaseQuery,WordPress.DB.DirectDatabaseQuery.NoCaching
			foreach ( $pagesresult as $pid ) {
				array_push( $exclude, $pid->ID );
			}
			$exclude_count = count( $exclude );
			for ( $x = 0;$x < $exclude_count;$x++ ) {
				$where .= ' AND ID != ' . $exclude[ $x ];
			}
		}
		return $where;
	}

	/**
	 * Checks if confirmation required.
	 *
	 * @return bool
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_confirmation_required() {
		if ( 1 === get_option( '_lp_membership', 1 ) ) {
			$return = true;
		} else {
			$return = false;
		}
		return (bool) apply_filters( 'wplegalpages_pro_confirmation_required', $return );
	}

	/**
	 * Enqueues Legal Pages Adult scripts.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_adult_scripts() {
		add_thickbox();
	}

	/**
	 * Renders Legal Pages Adult popup.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_adult_popup() {
		wp_enqueue_script( $this->plugin_name . 'adult-content' );
		$lp_general = get_option( 'lp_general' );
		?>
		<a id="inline" style="display:none" href="#data">This shows content of element who has id="data"</a>

		<div id="is_adult_thickbox" style="display:none">
			<div id="data">
				<p>This website contains content suitable for adults only . Please proceed only if you are above your country's legal age limit.</p>
				<a href="#" id="enter_site" style="text-decoration:none;">Yes,I am above my country's legal age limit (Enter)</a>
				<a href="<?php echo esc_url( $lp_general['leave-url'] ); ?>" style="text-decoration:none;" id="leave_site">Leave</a>
			</div>
		</div>
		<?php
	}

	/**
	 * Renders Legal Pages overlay popup.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_verify_overlay() {
		if ( ! $this->wplegalpages_pro_needs_verification() ) {
			return;
		}
		$lp_obj = new Wplegalpages_Pro();
		$lp_obj->wplegalpages_pro_enqueue_editor();
		?>
		<div id="lp-overlay-wrap">
			<?php do_action( 'wplegalpages_pro_before_modal' ); ?>
			<div id="lp-overlay">
				<?php
				do_action( 'wplegalpages_pro_before_form' );
				if ( $this->wplegalpages_pro_get_the_desc() ) {
					echo $this->wplegalpages_pro_get_the_desc(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				}
				do_action( 'wplegalpages_pro_after_form' );
				?>
			</div>
			<?php do_action( 'wplegalpages_pro_after_modal' ); ?>
		</div>
		<?php
	}

	/**
	 * Restrict content.
	 *
	 * @param string $content Content.
	 *
	 * @return string
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_restrict_content( $content ) {
		if ( ! $this->wplegalpages_pro_only_content_restricted() ) {
			return $content;
		}
		if ( is_singular() ) {
			return $content;
		}
		if ( ! $this->wplegalpages_pro_content_is_restricted() ) {
			return $content;
		}
		return sprintf(
			apply_filters( 'wplegalpages_pro_restricted_content_message', __( 'You must be atleast {age} years of age to view this content.<br>{form}', 'wplegalpages' ) . ' <a href="%2s">' . __( 'Please verify your age', 'wplegalpages' ) . '</a>.' ),
			esc_html( $this->wplegalpages_pro_get_minimum_age() ),
			esc_url( get_permalink( get_the_ID() ) )
		);
	}

	/**
	 * Verifies user.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_verify() {
		if ( isset( $_POST['lp-nonce'] ) ) {
			if ( ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['lp-nonce'] ) ), 'verify-age' ) ) {
				return;
			}
		} else {
			return;
		}

		$redirect_url = remove_query_arg( array( 'wplegalpages', 'verify-error' ), wp_get_referer() );

		$is_verified = false;

		$error = 1;

		$input_type = $this->wplegalpages_pro_get_input_type();

		switch ( $input_type ) {
			case 'checkbox':
				if ( isset( $_POST['lp_verify_confirm'] ) && 1 === (int) $_POST['lp_verify_confirm'] ) {
					$is_verified = true;
				} else {
					$error = 2;
				}
				break;
			default:
				$lp_verify_m = isset( $_POST['lp_verify_m'] ) ? sanitize_text_field( wp_unslash( $_POST['lp_verify_m'] ) ) : '';
				$lp_verify_d = isset( $_POST['lp_verify_d'] ) ? sanitize_text_field( wp_unslash( $_POST['lp_verify_d'] ) ) : '';
				$lp_verify_y = isset( $_POST['lp_verify_y'] ) ? sanitize_text_field( wp_unslash( $_POST['lp_verify_y'] ) ) : '';
				if ( checkdate( (int) $lp_verify_m, (int) $lp_verify_d, (int) $lp_verify_y ) ) :
					$age = $this->wplegalpages_pro_get_visitor_age( $lp_verify_y, $lp_verify_m, $lp_verify_d );
					if ( $age >= $this->wplegalpages_pro_get_minimum_age() ) {
						$is_verified = true;
					} else {
						$error = 3;
					} else :
						$error = 4;
				endif;
				break;
		}

		$is_verified = apply_filters( 'wplegalpages_pro_passed_verify', $is_verified );
		if ( true === $is_verified ) :
			do_action( 'wplegalpages_pro_was_verified' );
			if ( isset( $_POST['wplegalpages_pro_verify_remember'] ) ) {
				$cookie_duration = time() + ( $this->wplegapages_pro_get_cookie_duration() * 60 );
			} else {
				$cookie_duration = 0;
			}
			setcookie( 'wplegalpages', 1, $cookie_duration, COOKIEPATH, COOKIE_DOMAIN, false );
			wp_safe_redirect( esc_url_raw( $redirect_url ) . '?wplegalpages=' . wp_create_nonce( 'wplegalpages' ) );
			exit;
		else :
			do_action( 'wplegalpages_pro_was_not_verified' );
			wp_safe_redirect( esc_url_raw( add_query_arg( 'verify-error', $error, $redirect_url ) ) );
			exit;
		endif;
	}

	/**
	 * Verify user form.
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_register_form() {
		$text = '<p class="wplegalpages"><label for="_lp_confirm_age"><input type="checkbox" name="_lp_confirm_age" id="_lp_confirm_age" value="1" /> ';

		$text .= esc_html(
			sprintf(
				apply_filters(
					'wplegalpages_pro_registration_text',
					/* translators: 1: minimum age */
							esc_attr__( 'I am at least %1$s years old', 'wplegalpages' ),
					$this->wplegalpages_pro_get_minimum_age()
				)
			)
		);

		$text .= '</label></p><br />';
		echo esc_attr( $text );
	}

	/**
	 * Gets Legal Pages input types.
	 *
	 * @return mixed|void
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_input_type() {
		return apply_filters( 'wplegalpages_pro_get_input_type', get_option( '_lp_input_type', 'dropdowns' ) );
	}

	/**
	 * Checks whether verification is needed or not.
	 *
	 * @return bool
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_needs_verification() {
		$return = true;
		if ( $this->wplegalpages_pro_only_content_restricted() ) :
			$return = false;
			if ( is_singular() && $this->wplegalpages_pro_content_is_restricted() ) {
				$return = true;
			}
		endif;
		if ( isset( $_REQUEST['wplegalpages'] ) ) {
			if ( ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_REQUEST['wplegalpages'] ) ), 'wplegalpages' ) ) {
				$return = false;
			}
		}

		if ( 'guests' === get_option( '_lp_always_verify', 'guests' ) && is_user_logged_in() ) {
			$return = false;
		}

		if ( isset( $_COOKIE['wplegalpages'] ) ) {
			$return = false;
		}
		return (bool) apply_filters( 'wplegalpages_pro_needs_verification', $return );
	}

	/**
	 * Gets the Age verification description.
	 *
	 * @return bool|mixed|void
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_the_desc() {
		$find    = array( '{age}', '{form}' );
		$replace = array( $this->wplegalpages_pro_get_minimum_age(), $this->wplegalpages_pro_get_display_option() );
		$desc    = apply_filters( 'wplegalpages_pro_description', get_option( '_lp_description', __( 'You must be atleast {age} years of age to visit this site.<br>{form}', 'wplegalpages' ) ) );
		$strre   = str_replace( $find, $replace, $desc );
		if ( ! empty( $desc ) ) {
			return apply_filters( 'wplegalpages_pro_description', $strre );
		} else {
			return false;
		}
	}

	/**
	 * Returns restricted content.
	 *
	 * @return bool
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_only_content_restricted() {
		$only_content_restricted = 'content' === get_option( '_lp_require_for' ) ? true : false;
		$only_content_restricted = apply_filters( 'wplegalpages_pro_only_content_restricted', $only_content_restricted );
		return (bool) $only_content_restricted;
	}

	/**
	 * Checks if content is restricted or not.
	 *
	 * @param null $id ID.
	 *
	 * @return bool|mixed|void
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_content_is_restricted( $id = null ) {
		if ( is_null( $id ) ) {
			$id = get_the_ID();
		}
		$is_restricted = 1 === get_post_meta( $id, '_lp_needs_verify', true ) ? true : false;
		$is_restricted = apply_filters( 'wplegalpages_pro_is_restricted', $is_restricted, $id );
		return $is_restricted;
	}

	/**
	 * Returns minimum age for user.
	 *
	 * @return int
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_minimum_age() {
		$minimum_age = get_option( '_lp_minimum_age', 21 );
		$minimum_age = apply_filters( 'lp_minimum_age', $minimum_age );
		return (int) $minimum_age;
	}

	/**
	 * Returns display options for verify form.
	 *
	 * @return mixed|string|void
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_display_option() {
		$html = '';
		if ( 'date' === get_option( '_lp_display_option', 'date' ) ) {
			$html = $this->wplegalpages_pro_verify_form();
		} else {
			$html = $this->wplegalpages_pro_age_button();
		}
		return $html;
	}

	/**
	 * Legal Pages verify form for Date field option.
	 *
	 * @return mixed|void
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_verify_form() {
		return $this->wplegalpages_pro_get_verify_form();
	}

	/**
	 * Legal Pages verify form for date field option.
	 *
	 * @return mixed|void
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_verify_form() {
		$input_type          = $this->wplegalpages_pro_get_input_type();
		$submit_button_label = apply_filters( 'wplegalpages_pro_form_submit_label', __( 'VERIFY AGE &raquo;', 'wplegalpages' ) );
		$form                = '';
		$form               .= '<form id="lp_verify_form" action="' . esc_url( home_url( '/' ) ) . '" method="post">';
		$error               = isset( $_GET['verify-error'] ) ? sanitize_text_field( wp_unslash( $_GET['verify-error'] ) ) : false; // phpcs:ignore WordPress.Security.NonceVerification
		if ( $error ) :
			$homeurl = get_home_url();
			$data    = apply_filters( 'wplegalpages_pro_invalid_description', get_option( '_lp_invalid_description', __( 'We are Sorry.', 'wplegalpages' ) ) );
			$form   .= <<<FORM
					<a id="inline" style="display:none" href="#data">This shows content of element who has id="data"</a>

					<div id="is_adult_thickbox" style="display:none">
						 <div id="data">
						 	$data
						<br>
						<a href="$homeurl">Go Back to HomePage</a>
						</div>
						</div>
					<script>
						jQuery(document).ready(function($) {

					tb_show("", "#TB_inline?inlineId=is_adult_thickbox&modal=true", false);

					if( $(window).width() == 640 ){
					window_width = 570;
					}else
					window_width = $(window).width();

					if( TB_WIDTH > window_width ){
					$("#TB_window").css({marginTop: 0, marginLeft: 0, width: '90%', left: '5%',  top:'10%', height:'auto'});
					$("#TB_ajaxContent, #TB_iframeContent").css({width: 'auto', height:'auto'});
					$("#TB_closeWindowButton").css({fontSize: '1.2em', marginRight: '5px'});
					}
					else{
					$("#TB_window").css({marginLeft: '-' + parseInt((TB_WIDTH / 2),10) + 'px',width: + parseInt(TB_WIDTH) + 'px',height: + parseInt(TB_HEIGHT) + 'px'});
					$("#TB_ajaxContent, #TB_iframeContent").css({width: + parseInt(TB_WIDTH) + 'px',height: + parseInt(TB_HEIGHT) + 'px'});
					}

					$('#data').css( {'margin'     : '0 auto',
								'font-weight':  'normal',
								'line-height':  '5em'
							 } );

					$('#TB_ajaxContent.TB_modal').css({ 'display' : 'flex',
					'position' : 'fixed',
					'text-align' : 'center',
					'align-items' : 'center'

					})
				});
				</script>
FORM;
		endif;
		do_action( 'wplegalpages_pro_form_before_inputs' );
		$form .= wp_nonce_field( 'verify-age', 'lp-nonce' );
		switch ( $input_type ) {
			case 'dropdowns':
				$form .= '<p><select name="lp_verify_m" id="lp_verify_m">';
				foreach ( range( 1, 12 ) as $month ) :
					$month_name = gmdate( 'F', mktime( 0, 0, 0, $month, 1 ) );
					$form      .= '<option value="' . $month . '">' . $month_name . '</option>';
				endforeach;
				$form .= '</select> - <select name="lp_verify_d" id="lp_verify_d">';
				foreach ( range( 1, 31 ) as $day ) :
					$form .= '<option value="' . $day . '">' . esc_html( zeroise( $day, 2 ) ) . '</option>';
				endforeach;
				$form .= '</select> - <select name="lp_verify_y" id="lp_verify_y">';
				foreach ( range( 1910, gmdate( 'Y' ) ) as $year ) :
					$selected = gmdate( 'Y' ) === $year ? 'selected="selected"' : '';
					$form    .= '<option value="' . $year . '" ' . $selected . '>' . $year . '</option>';
				endforeach;
				$form .= '</select></p>';
				break;
			case 'inputs':
				$form .= '<p><input type="text" name="lp_verify_m" id="lp_verify_m" maxlength="2" value="" placeholder="MM" /> - <input type="text" name="lp_verify_d" id="lp_verify_d" maxlength="2" value="" placeholder="DD" /> - <input type="text" name="lp_verify_y" id="lp_verify_y" maxlength="4" value="" placeholder="YYYY" /></p>';
				break;
			case 'checkbox':
				$form .= '<p><label for="lp_verify_confirm"><input type="checkbox" name="lp_verify_confirm" id="lp_verify_confirm" value="1" /> ';
				$form .= esc_html(
					sprintf(
						apply_filters(
							'lp_confirm_text',
							/* translators: 1: minimum age */
							esc_attr__( 'I am at least %1$s years old', 'wplegalpages' )
						),
						$this->wplegalpages_pro_get_minimum_age()
					)
				) . '</label></p>';
				break;
		};
		do_action( 'wplegalpages_pro_form_after_inputs' );
		$form .= '<div class="buttons-set>"<p class="submit"><label for="lp_verify_remember"><input type="checkbox" name="lp_verify_remember" id="lp_verify_remember" value="1" /> ' . esc_html__( 'Remember me', 'wplegalpages' ) . '</label>';
		$form .= '<input type="submit" name="lp_verify" id="lp_verify" value="' . esc_attr( $submit_button_label ) . '" /></p></div>';
		$form .= '</form>';
		return apply_filters( 'wplegalpages_pro_verify_form', $form );
	}

	/**
	 * Legal Pages verify form for button option.
	 *
	 * @return string
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_age_button() {
		return $this->wplegalpages_pro_get_age_button();

	}

	/**
	 * Legal Pages verify form for button option.
	 *
	 * @return string
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_age_button() {
		$lp_eu_button_text    = get_option( 'lp_eu_button_text' );
		$lp_eu_button_text_no = get_option( 'lp_eu_button_text_no' );
		$data                 = apply_filters( 'wplegalpages_pro_invalid_description', get_option( '_lp_invalid_description', __( 'We are Sorry.', 'wplegalpages' ) ) );
		$form                 = <<<FORM
                <div class="verify">
                        <div class="buttons-set">
                        <span class="agebutton">
                            <input type="submit" name="lp_verify" id="lp_verify_yes" value=" $lp_eu_button_text " />
                            </span>
                            <span class="agebutton">
                        <input type="submit" name="lp_verify" id="lp_verify_no" value=" $lp_eu_button_text_no " href="#" />
                        </span>
                        <br>
                        </div>
                </div>
                <a id="inline" style="display:none" href="#data">This shows content of element who has id="data"</a>
    
                <div id="is_adult_thickbox" style="display:none">
                     <div id="data">
                        $data
                    </div>
                    </div>
    
    
                <script>
                    jQuery(document).ready(function($) {
                            $('#lp_verify_yes').click(function(){
                                $.cookie("wplegalpages", 1, { expires : 1 });
                            location.reload();
                            });
    
                            $('#lp_verify_no').click(function(){
                                tb_show("", "#TB_inline?inlineId=is_adult_thickbox&modal=true", false);
    
                    if( $(window).width() == 640 ){
                        window_width = 570;
                    }else
                        window_width = $(window).width();
    
                    if( TB_WIDTH > window_width ){
                        $("#TB_window").css({marginTop: 0, marginLeft: 0, width: '90%', left: '5%',  top:'10%', height:'auto'});
                        $("#TB_ajaxContent, #TB_iframeContent").css({width: 'auto', height:'auto'});
                        $("#TB_closeWindowButton").css({fontSize: '1.2em', marginRight: '5px'});
                    }
                    else{
                        $("#TB_window").css({marginLeft: '-' + parseInt((TB_WIDTH / 2),10) + 'px',width: + parseInt(TB_WIDTH) + 'px',height: + parseInt(TB_HEIGHT) + 'px'});
                        $("#TB_ajaxContent, #TB_iframeContent").css({width: + parseInt(TB_WIDTH) + 'px',height: + parseInt(TB_HEIGHT) + 'px'});
                    }
    
                    $('#data').css( {'margin'     : '5% 1%',
                                            'font-weight':  'normal',
                                            'line-height':  '5em',
                                            'text-align': 'center'
                                         } );
    
                    $('#TB_ajaxContent.TB_modal').css({ 'display' : 'flex',
                        'position' : 'fixed',
                        'align-items' : 'center',
                        'justify-content' : 'center'
    
                    })
    
                         });
                    });
                    </script>
FORM;
		return $form;
	}

	/**
	 * Get visitor age.
	 *
	 * @param int $year Year.
	 * @param int $month Month.
	 * @param int $day Day.
	 *
	 * @return int
	 *
	 * @since 7.0
	 */
	public function wplegalpages_pro_get_visitor_age( $year, $month, $day ) {
		$age        = 0;
		$birthday   = new DateTime( $year . '-' . $month . '-' . $day );
		$phpversion = phpversion();
		if ( $phpversion >= '5.3' ) :
			$current = new DateTime( current_time( 'mysql' ) );
			$age     = $birthday->diff( $current );
			$age     = $age->format( '%y' );
		else :
			list( $year, $month, $day ) = explode( '-', $birthday->format( 'Y-m-d' ) );
			$year_diff                  = date_i18n( 'Y' ) - $year;
			$month_diff                 = date_i18n( 'm' ) - $month;
			$day_diff                   = date_i18n( 'd' ) - $day;
			if ( $month_diff < 0 ) {
				$year_diff--;
			} elseif ( ( 0 === $month_diff ) && ( $day_diff < 0 ) ) {
				$year_diff--;
			}
			$age = $year_diff;
		endif;
		return (int) $age;
	}

	/**
	 * Get cookie duration.
	 *
	 * @return int|mixed|void
	 *
	 * @since 7.0
	 */
	public function wplegapages_pro_get_cookie_duration() {
		$cookie_duration = get_option( '_lp_cookie_duration', 720 );
		$cookie_duration = (int) apply_filters( 'lp_cookie_duration', $cookie_duration );
		return $cookie_duration;
	}
}
