<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://club.wpeka.com
 * @since             7.0
 * @package           Wplegalpages_Pro
 *
 * @wordpress-plugin
 * Plugin Name:       WP Legal Pages Pro
 * Plugin URI:        https://club.wpeka.com/
 * Description:       WP Legal Pages is a simple 1 click legal page management plugin. You can quickly add in legal pages to your WordPress sites, manage templates, edit templates, create disclosure snippets, create pages all driven off custom short codes. Furthermore the business information you fill in the general settings will be automatically filled into the appropriate places within the pages due to our custom integration system we have. The icing on the cake is the hosting of unlimited popups that force the visitor to agree to your terms before the page unlocks. This plugin is truly unique and according to our buyers 'Truly Awesome'!
 * Version:           7.6
 * Author:            WPEkaClub
 * Author URI:        https://club.wpeka.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wplegalpages
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


// Load WC_AM_Client class if it exists.
if ( ! class_exists( 'WC_AM_Client_2_7' ) ) {
	require_once plugin_dir_path( __FILE__ ) . 'auto-updates/wc-am-client.php';
}

// Instantiate WC_AM_Client class object if the WC_AM_Client class is loaded.
if ( class_exists( 'WC_AM_Client_2_7' ) ) {
	$wcam_lib = new WC_AM_Client_2_7( __FILE__, '', '7.6', 'plugin', 'https://club.wpeka.com/', 'WPLegalPages Pro' );
}

require_once 'class-wpltgm-plugin-activation.php';
add_action( 'tgmpa_register', 'wplegalpages_pro_register_required_plugins' );

/**
 * Install required plugins for Pro Version.
 *
 * @since 7.0
 */
function wplegalpages_pro_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		array(
			'name'               => 'WP Legal Pages',
			'slug'               => 'wplegalpages',
			'version'            => '2.3.0',
			'required'           => true,
			'force_activation'   => true,
			'force_deactivation' => true,
		),

	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'wplegalpages',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'plugins.php',            // Parent menu slug.
		'capability'   => 'manage_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => false,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => true,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.

	);
	wpl_tgmpa( $plugins, $config );
}
/**
 * Currently plugin version.
 * Start at version 7.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
if ( ! defined( 'WPLEGALPAGES_PRO_VERSION' ) ) {
	define( 'WPLEGALPAGES_PRO_VERSION', '7.6' );
}
if ( ! defined( 'WPLEGALPAGES_PRO_PLUGIN_URL' ) ) {
	define( 'WPLEGALPAGES_PRO_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
}
if ( ! defined( 'WPLPP_SUFFIX' ) ) {
	define( 'WPLPP_SUFFIX', ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min' );
}
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wplegalpages-pro-activator.php
 */
function activate_wplegalpages_pro() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wplegalpages-pro-activator.php';
	Wplegalpages_Pro_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wplegalpages-pro-deactivator.php
 */
function deactivate_wplegalpages_pro() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wplegalpages-pro-deactivator.php';
	Wplegalpages_Pro_Deactivator::deactivate();
}

/**
 * The code that runs during plugin uninstallation.
 */
function delete_wplegalpages_pro() {
	update_option( '_lp_pro_installed', 0 );
}

register_activation_hook( __FILE__, 'activate_wplegalpages_pro' );
register_deactivation_hook( __FILE__, 'deactivate_wplegalpages_pro' );
register_uninstall_hook( __FILE__, 'delete_wplegalpages_pro' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wplegalpages-pro.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    7.0
 */
function run_wplegalpages_pro() {

	$plugin = new Wplegalpages_Pro();
	$plugin->run();

}
run_wplegalpages_pro();
